@@ -14,3 +14,7 @@ class TestAbout(TestCase):
         self.assertTrue(about.version)
         import semver
         self.assertTrue(semver.VersionInfo.parse(about.version))
+
+    def test_python_fstring(self):
+        true = f"this is {True}"
+        self.assertEqual(f"{true}", true)
