@@ -263,17 +263,11 @@ class TestProperties(TestBetamax):
         initial_description = 'Property created to test clearing values.'
         initial_unit = 'mm'
 
-        self.prop_model.edit(
-            name=initial_name,
-            description=initial_description,
-            unit=initial_unit
-        )
+        self.prop_model.edit(name=initial_name, description=initial_description, unit=initial_unit)
 
         # Edit without mentioning values, everything should stay the same
         new_name = 'Property second name'
-        self.prop_model.edit(
-            name=new_name
-        )
+        self.prop_model.edit(name=new_name)
 
         # testing
         self.assertEqual(self.prop_model.name, new_name)
@@ -281,11 +275,7 @@ class TestProperties(TestBetamax):
         self.assertEqual(self.prop_model.unit, initial_unit),
 
         # Edit with clearing the values, name and status cannot be cleared
-        self.prop_model.edit(
-            name=None,
-            description=None,
-            unit=None
-        )
+        self.prop_model.edit(name=None, description=None, unit=None)
 
         self.assertEqual(self.prop_model.name, new_name)
         self.assertEqual(self.prop_model.description, str())
